<?php
/**
 * Dynamic CSS for the frontend.
 *
 * @package Saddle
 */

defined( 'WPINC' ) || exit;

/**
 * Helper function.
 * Merge and combine the CSS elements.
 *
 * @param  string|array $elements An array of our elements.
 *                                If we use a string then it is directly returned.
 * @return string
 */
function saddle_implode( $elements = array() ) {

	if ( ! is_array( $elements ) ) {
		return $elements;
	}

	// Make sure our values are unique.
	$elements = array_unique( $elements );

	// Sort elements alphabetically.
	// This way all duplicate items will be merged in the final CSS array.
	sort( $elements );

	// Implode items and return the value.
	return implode( ',', $elements );

}

/**
 * Maps elements from dynamic css to the selector.
 *
 * @param  array  $elements The elements.
 * @param  string $selector The selector.
 * @return array
 */
function saddle_map_selector( $elements, $selector ) {
	$array = array();

	foreach ( $elements as $element ) {
		$array[] = $element . $selector;
	}

	return $array;
}

/**
 * Map CSS selectors from values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function saddle_map_css_selectors( &$css, $values ) {
	if ( isset( $values['css-selectors'] ) ) {
		$elements = $values['css-selectors'];
		unset( $values['css-selectors'] );

		$css[ $elements ] = $values;
	}
}

/**
 * Merge CSS values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function saddle_merge_value( &$css, $values ) {
	foreach ( $values as $id => $val ) {
		$css[ $id ] = $val;
	}
}

/**
 * Format of the $css array:
 * $css['media-query']['element']['property'] = value
 *
 * If no media query is required then set it to 'global'
 *
 * If we want to add multiple values for the same property then we have to make it an array like this:
 * $css[media-query][element]['property'][] = value1
 * $css[media-query][element]['property'][] = value2
 *
 * Multiple values defined as an array above will be parsed separately.
 */
function saddle_dynamic_css_array() {

	global $wp_version;

	$css       = array();
	$c_page_id = saddle()->get_page_id();

	// Site Background.
	$css['global']['html body'] = Saddle_Sanitize::background( saddle_get_settings( 'theme_background' ) );

	// Header Background.
	$css['global']['#site-header'] = Saddle_Sanitize::background( saddle_get_settings( 'header_background' ) );

	// Logo Font.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'saddle_logo' ) ) );
	// Footer Logo Font.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'saddle_footer_logo' ) ) );
	// Primary Navigation font.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'primary_navigation_font' ) ) );
	// Content Font.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'content_font' ) ) );
	// Pagination.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'pagination_font' ) ) );
	// Archive Pages font.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'archive_post_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'archive_post_excerpt_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'archive_meta_info_font' ) ) );
	// Single post title font.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'single_title_font' ) ) );
	// Single post author info font.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'single_author_meta_info_font' ) ) );
	// Single Page titles font.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'single_page_titles_font' ) ) );
	// Single subscribe box.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'single_subscribe_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'single_subscribe_text_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'single_subscribe_input_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'single_subscribe_submit_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'single_subscribe_small_text_font' ) ) );
	// Author Box.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'authorbox_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'authorbox_author_name_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'authorbox_text_font' ) ) );
	// Footer Nav.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'footer_nav_font' ) ) );
	// Sidebar widget title font.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'sidebar_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'sidebar_buttons_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'submit_button_font' ) ) );
	// Sidebar widget font.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'mts_widget_links' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'default_widget_links' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'sidebar_url_bigthumb' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'sidebar_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'sidebar_font_bigthumb' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'sidebar_postinfo_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'sidebar_postinfo_font_bigthumb' ) ) );
	// Tab widget title font.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'tabs_title_font' ) ) );
	// Footer widget title font.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'footer_saddle_logo' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'top_footer_title_font' ) ) );
	// Footer link font.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'top_footer_link_font' ) ) );
	// Footer MTS link font.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'mts_footer_widget_links' ) ) );
	// Footer widget font.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'top_footer_font' ) ) );
	// Copyrights section font.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'copyrights_font' ) ) );
	// Fields font.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'fields_font' ) ) );
	// H1 title in the content.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'h1_headline' ) ) );
	// H2 title in the content.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'h2_headline' ) ) );
	// H3 title in the content.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'h3_headline' ) ) );
	// H4 title in the content.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'h4_headline' ) ) );
	// H5 title in the content.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'h5_headline' ) ) );
	// H6 title in the content.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'h6_headline' ) ) );

	// Footer background.
	$css['global']['#site-footer'] = Saddle_Sanitize::background( saddle_get_settings( 'mts_footer_background' ) );
	// Copyrights background.
	$css['global']['.copyrights'] = Saddle_Sanitize::background( saddle_get_settings( 'mts_copyrights_background' ) );

	saddle_dynamic_css_skin( $css );
	saddle_sidebar_position( $css );
	saddle_header( $css );
	saddle_header_featured( $css );
	saddle_sidebar_styling( $css );
	saddle_home_sections( $css );
	saddle_page_titles( $css );
	saddle_post_layouts( $css );
	saddle_post_pagination( $css );
	saddle_footer( $css );
	saddle_copyrights( $css );
	saddle_single( $css );
	saddle_single_social_buttons( $css );
	saddle_archive_post( $css );
	saddle_misc_css( $css );
	saddle_custom_posts( $css );

	return apply_filters( 'saddle_dynamic_css_array', $css );
}

/**
 * Skin CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function saddle_dynamic_css_skin( &$css ) {

	// Colors.
	$primary_color_scheme   = Saddle_Sanitize::color( saddle_get_settings( 'primary_color_scheme' ) );
	$secondary_color_scheme = Saddle_Sanitize::color( saddle_get_settings( 'secondary_color_scheme' ) );

	// Text Color.
	$elements = array(
		'a',
		'body a:hover',
		'.woocommerce ul.products li.product .price',
		'.product_list_widget .amount',
		'.woocommerce div.product p.price, .woocommerce div.product span.price',
		'.textwidget a',
		'#wp-calendar td#today',
		'.pnavigation2 a',
		'#tabber .inside li a:hover',
		'.fn a',
		'.widget .wp_review_tab_widget_content a',
		'.sidebar .wpt_widget_content a',
		'.related-posts .title a:hover',
		'blockquote:after',
		'article ul li::before',
		'.single .pagination a .current:hover',
		'blockquote::before',
		'.postauthor h5 a:hover',
		'.related-readmore a',
		'.widget .wpt_widget_content #tags-tab-content ul li a',
		'.widget .sbutton:hover',
		'.shareit-circular.standard .share-text',
		'.breadcrumb a',
		'.rank-math-breadcrumb a',
		'.layout-default .latestPost .post-info a',
		'.single_post .post-info a',
		'.layout-default .readMore a:hover',
		'.instagram-button a',
		'.blog-section .readMore a',
		'.widget #wp-subscribe input.submit',
		'.post-type-archive-contests .readMore a:hover', // Contest CPT
		'.post-type-archive-contests .address',
	);

	$css['global'][ saddle_implode( $elements ) ]['color'] = $primary_color_scheme;
	// social svg hover color.
	$css['global']['.shareit-circular.standard svg:hover']['fill'] = $primary_color_scheme;

	// Text Color Important.
	$elements = array(
		'.widget .review_thumb_large .review-result',
		'.widget .review_thumb_large .review-total-only.large-thumb',
		'.review-total-only.small-thumb .review-result-wrapper i',
	);
	$css['global'][ saddle_implode( $elements ) ]['color'] = $primary_color_scheme . '!important';

	// Background Color.
	$elements = array(
		'.button',
		'.button.light:hover',
		'.blog-section .readMore a:hover',
		'.instagram-button a:hover',
		'.widget #wp-subscribe input.submit:hover',
		'.pace .pace-progress',
		'#mobile-menu-wrapper ul li a:hover',
		'.pagination a:hover',
		'.single .pagination a:hover .current',
		'.navigation #wpmm-megamenu .wpmm-pagination a',
		'.wpmm-megamenu-showing.wpmm-light-scheme',
		'#move-to-top:hover',
		'#tabber ul.tabs li a.selected',
		'.navigation ul .sfHover a',
		'.widget-slider .slide-caption',
		'.owl-prev:hover, .owl-next:hover',
		'#wpmm-megamenu .review-total-only',
		'#searchsubmit',
		'#commentform input#submit:hover',
		'#mtscontact_submit:hover',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-handle',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-range',
		'.woocommerce span.onsale',
		'.woocommerce .bypostauthor:after',
		'.woocommerce-account .woocommerce-MyAccount-navigation li.is-active',
		'.widget .widget_wp_review_tab .review-total-only.large-thumb',
		'.f-widget .wp_review_tab_widget_content ul.wp-review-tabs li.selected a::before',
		'.f-widget .wpt_widget_content ul.wpt-tabs li.selected a::before',
		'.f-widget .widget #wp-subscribe input.submit:hover',
		'.f-widget .button:hover',
		'.f-widget .instagram-button a:hover',
		'.pagination .nav-previous a:hover',
		'.pagination .nav-next a:hover',
		'.single-subscribe .widget #wp-subscribe input.submit:hover',
		'.event-arrow a:hover',
		'.woocommerce a.button:hover', // WooCommerce
		'.woocommerce-page a.button:hover',
		'.woocommerce button.button:hover',
		'.woocommerce-page button.button:hover',
		'.woocommerce input.button:hover',
		'.woocommerce-page input.button:hover',
		'.woocommerce #respond input#submit:hover',
		'.woocommerce-page #respond input#submit:hover',
		'.woocommerce #content input.button:hover',
		'.woocommerce-page #content input.button:hover',
		'.woocommerce a.button:hover',
		'.woocommerce-page a.button:hover',
		'.woocommerce button.button:hover',
		'.woocommerce-page button.button:hover',
		'.woocommerce input.button:hover',
		'.woocommerce-page input.button:hover',
		'.woocommerce #respond input#submit:hover',
		'.woocommerce-page #respond input#submit:hover',
		'.woocommerce #content input.button:hover',
		'.woocommerce-page #content input.button:hover',
		'.woocommerce #respond input#submit.alt.disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled[disabled]:hover',
		'.woocommerce a.button.alt:disabled:hover',
		'.woocommerce a.button.alt:disabled[disabled]:hover',
		'.woocommerce button.button.alt.disabled:hover',
		'.woocommerce button.button.alt:disabled[disabled]:hover',
		'#add_payment_method .wc-proceed-to-checkout a.checkout-button:hover',
		'.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:hover',
		'.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button:hover',
		'.woocommerce a.button.alt:hover',
		'.woocommerce button.button.alt:hover',
		'.woocommerce input.button.alt:hover',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit:hover',
		'.woocommerce .widget.widget_product_search button[type="submit"]:hover',
		'.woocommerce-page .widget.widget_product_search button[type="submit"]:hover',
		'.woocommerce div.product form.cart .button:hover',
	);

	$css['global'][ saddle_implode( $elements ) ]['background-color'] = $primary_color_scheme;

	$css['@media screen and (max-width: 865px)']['.navigation.mobile-menu-wrapper']['background-color'] = Saddle_Sanitize::color( saddle_get_settings( 'nav_background' ) );

	// Background Color Important.
	$elements = array(
		'.widget .wpt_widget_content #tags-tab-content ul li a:hover ',
	);
	$css['global'][ saddle_implode( $elements ) ]['background-color'] = $primary_color_scheme . '!important';

	// Border Color.
	$elements = array(
		'.page-numbers.current',
		'.pagination a:hover',
		'.widget .wpt_widget_content #tags-tab-content ul li a',
	);

	$css['global'][ saddle_implode( $elements ) ]['border-color'] = $primary_color_scheme;

	// Secondary text Color.
	$secondary_elements = array(
		'.reply a:hover',
		'.services-wrapper .text-wrapper a:hover h3',
		'.blog-wrapper .title:hover',
		'.latestPost .title a:hover',
		'.related-posts .title a:hover',
		'.shareit-circular.standard .fa:hover',
		'.layout-default .latestPost .title a:hover',
		'.layout-default .latestPost .post-info a:hover',
		'.layout-full .latestPost .post-info a:hover',
		'.layout-full .wrapper .posts-share-buttons a:hover',
		'.layout-grid .latestPost .title a:hover',
		'.layout-grid .latestPost .post-info a:hover',
		'#sidebar .widget li a:hover',
		'#sidebar .widget li.horizontal-small .post-title a:hover',
		'.f-widget .widget li a:hover',
		'.f-widget .widget li.horizontal-small .post-title a:hover',
		'.f-widget .widget .vertical-small .post-title a:hover',
		'.featured-section .title span',
		'.aboutme-widget .aboutme-social a:hover',
		'.instagram-button a:hover',
		'.toggle-menu .toggle-caret .fa',
		'.widget.social-profile-icons a:hover',
		'.widget .sbutton',
		'.single_post .post-info a:hover',
		'#commentform p .fa',
		'.woocommerce nav.woocommerce-pagination ul li span.current', // WooCommerce
		'.woocommerce nav.woocommerce-pagination ul li a:hover',
		'.woocommerce nav.woocommerce-pagination ul li a:focus',
		'.woocommerce-page nav.woocommerce-pagination ul li span.current',
		'.woocommerce-page nav.woocommerce-pagination ul li a:hover',
		'.woocommerce-page nav.woocommerce-pagination ul li a:focus',
		'.horses-info .selector', // Horse CPT
		'.post-type-archive-horses .latestPost .title a:hover',
		'.post-type-archive-contests .title a:hover', // Contest CPT
		'.post-type-archive-contests .post-info a:hover',
	);

	$css['global'][ saddle_implode( $secondary_elements ) ]['color'] = $secondary_color_scheme;

	// Secondary background Color.
	$secondary_elements = array(
		'.owl-prev',
		'.owl-next',
		'.single-subscribe .widget #wp-subscribe input.submit',
		'.button:hover',
		'.button.light',
		'.blog-section .readMore a',
		'.instagram-button a',
		'.widget #wp-subscribe input.submit',
		'.tags a:hover',
		'#sidebar .widget .tagcloud a:hover',
		'.f-widget .tagcloud a:hover',
		'#commentform input#submit',
		'#mtscontact_submit',
		'.event-arrow a::before',
		'.event-arrow a::after',
		'.woocommerce a.button',
		'.woocommerce-page a.button',
		'.woocommerce button.button',
		'.woocommerce-page button.button',
		'.woocommerce input.button',
		'.woocommerce-page input.button',
		'.woocommerce #respond input#submit',
		'.woocommerce-page #respond input#submit',
		'.woocommerce #content input.button',
		'.woocommerce-page #content input.button',
		'.woocommerce a.button',
		'.woocommerce-page a.button',
		'.woocommerce button.button',
		'.woocommerce-page button.button',
		'.woocommerce input.button',
		'.woocommerce-page input.button',
		'.woocommerce #respond input#submit',
		'.woocommerce-page #respond input#submit',
		'.woocommerce #content input.button',
		'.woocommerce-page #content input.button',
		'.woocommerce #respond input#submit.alt.disabled',
		'.woocommerce #respond input#submit.alt:disabled[disabled]',
		'.woocommerce a.button.alt:disabled',
		'.woocommerce a.button.alt:disabled[disabled]',
		'.woocommerce button.button.alt.disabled',
		'.woocommerce button.button.alt:disabled[disabled]',
		'.woocommerce input.button.alt.disabled',
		'#add_payment_method .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce-cart .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce #respond input#submit.alt',
		'.woocommerce a.button.alt',
		'.woocommerce button.button.alt',
		'.woocommerce input.button.alt',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit',
		'.woocommerce .widget.widget_product_search button[type="submit"]',
		'.woocommerce-page .widget.widget_product_search button[type="submit"]',
		'.woocommerce div.product form.cart .button',
		'.widget .wp_review_tab_widget_content ul.wp-review-tabs li.selected a::before',
		'.widget .wpt_widget_content ul.wpt-tabs li.selected a::before',
		'.horses-info li::before', // Horse CPT
	);

	$css['global'][ saddle_implode( $secondary_elements ) ]['background-color'] = $secondary_color_scheme;

	// Border Color.
	$secondary_elements = array(
		'.widget.widget_categories li',
		'.widget.widget_archive li',
		'.widget.widget_pages li',
		'.widget.widget_meta li',
		'.widget.widget_recent_comments li',
		'.widget.widget_recent_entries li',
		'.widget.widget_rss li',
		'.widget.widget_nav_menu li',
		'.f-widget .tagcloud a:hover',
		'.f-widget .widget .wpt_widget_content #tags-tab-content ul li a:hover',
		'blockquote',
		'.events-section .events-wrapper li',
		'.post-type-archive-contests .contestPost', // Contest CPT
	);

	$css['global'][ saddle_implode( $secondary_elements ) ]['border-color'] = $secondary_color_scheme;

}

/**
 * Sidebar Position
 *
 * @param array $css Array of dynamic CSS.
 */
function saddle_sidebar_position( &$css ) {

	// Sidebar position.
	$sidebar_position = saddle_get_settings( 'theme_layout' );

	$sidebar_metabox_location = '';
	if ( is_page() || is_single() ) {
		$sidebar_metabox_location = get_post_meta( get_the_ID(), '_mts_sidebar_location', true );
	}

	if ( 'right' !== $sidebar_metabox_location && ( 'sclayout' === $sidebar_position || 'left' === $sidebar_metabox_location ) ) {
		$css['global']['.article']['float']                = 'right';
		$css['global']['.sidebar.c-4-12']['float']         = 'left';
		$css['global']['.sidebar.c-4-12']['padding-right'] = 0;

		if ( null !== saddle_get_settings( 'mts_social_button_position' ) && 'floating' === saddle_get_settings( 'mts_social_button_position' ) ) {

			$shareit_class = array(
				'.sclayout .shareit.shareit-default.floating',
				'.sclayout .shareit.standard.floating',
				'.sclayout .shareit.shareit-circular.floating',
			);

			$css['global'][ saddle_implode( $shareit_class ) ]['left']  = 'auto';
			$css['global'][ saddle_implode( $shareit_class ) ]['right'] = '0px';

			$css['global'][ saddle_implode( $shareit_class ) ]['margin-left']  = '0px';
			$css['global'][ saddle_implode( $shareit_class ) ]['margin-right'] = saddle_px_to_rem( '100px' );
		}
	}
	if ( 'mts_nosidebar' == mts_custom_sidebar() ) {
		$css['global']['.single-full-header']['width'] = '100%';
	}
}

/**
 * Header
 *
 * @param array $css Array of dynamic CSS.
 */
function saddle_header( &$css ) {

	$header_icons           = saddle_get_settings( 'header_social_icons' );
	$header_layout          = saddle_get_settings( 'header_styles' );
	$header_height          = saddle_get_settings( 'header_height' );
	$secondary_color_scheme = Saddle_Sanitize::color( saddle_get_settings( 'secondary_color_scheme' ) );
	$header_bg_position     = saddle_get_settings( 'header_background_position' );

	if ( 'header-default' === $header_layout ) {
		$css['global']['#site-header']['max-height'] = $header_height ? $header_height . 'px' : '100%';
	}

	// Header background position
	if ( ! is_page_template( 'page-home.php' ) ) {
		$css['global']['#site-header']['background-position'] = $header_bg_position;
	}

	if ( saddle_get_settings( 'sticky_nav' ) ) {
		$css['global']['#header.sticky-navigation-active']['background'] = $secondary_color_scheme;
		$css['global']['#header.sticky-navigation-active']['max-height'] = '114px';
	}

	// Header.
	$header_class = array(
		'#header',
	);

	saddle_merge_value( $css['global'][ saddle_implode( $header_class ) ], Saddle_Sanitize::margin( saddle_get_settings( 'header_margin' ) ) );
	saddle_merge_value( $css['global'][ saddle_implode( $header_class ) ], Saddle_Sanitize::padding( saddle_get_settings( 'header_padding' ) ) );

	// Header Border.
	$header_border = Saddle_Sanitize::border( saddle_get_settings( 'header_border' ) );
	$css['global'][ saddle_implode( $header_class ) ][ $header_border['direction'] ] = $header_border ['value'];

	// Nav styling.
	// Nav color.
	$css['global']['#primary-navigation .navigation ul ul a']['color'] = Saddle_Sanitize::color( saddle_get_settings( 'main_navigation_dropdown_color' ) );

	$css['global']['#primary-navigation .navigation ul ul a:hover']['color'] = Saddle_Sanitize::color( saddle_get_settings( 'main_navigation_dropdown_hover_color' ) );

	// Nav Background.
	$nav_bg = Saddle_Sanitize::color( saddle_get_settings( 'nav_background' ) );
	if ( is_page_template( 'page-home.php' ) && 'header-layout2' !== $header_layout ) {
		$css['global']['#primary-navigation']['background-color'] = hex2rgba( $nav_bg, '0.9' );
	} else {
		$css['global']['#primary-navigation']['background-color'] = $nav_bg;
	}

	// Nav Dropdown Background.
	$css['global']['.navigation ul ul']['background-color'] = Saddle_Sanitize::color( saddle_get_settings( 'main_nav_dropdown_bg' ) );

	// Nav margin and Padding.
	saddle_merge_value( $css['global']['#primary-navigation'], Saddle_Sanitize::margin( saddle_get_settings( 'header_nav_margin' ) ) );
	saddle_merge_value( $css['global']['#primary-navigation'], Saddle_Sanitize::padding( saddle_get_settings( 'header_nav_padding' ) ) );

	// Header layout 2
	if ( 'header-layout2' === $header_layout ) {

		saddle_merge_value( $css['global']['#primary-navigation'], Saddle_Sanitize::margin( saddle_get_settings( 'header2_nav_margin' ) ) );

		saddle_merge_value( $css['global']['#primary-navigation'], Saddle_Sanitize::padding( saddle_get_settings( 'header2_nav_padding' ) ) );

	}

	// Social icons.
	if ( ! empty( $header_icons ) && is_array( $header_icons ) && 'header-layout2' === $header_layout ) :
		foreach ( $header_icons as $header_icon ) :

			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['background-color'] = Saddle_Sanitize::color( $header_icon['header_icon_bgcolor'] );

			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] . ':hover' ]['background-color'] = Saddle_Sanitize::color( $header_icon['header_icon_hover_bgcolor'] );

			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['color'] = Saddle_Sanitize::color( $header_icon['header_icon_color'] );

			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] . ':hover' ]['color'] = Saddle_Sanitize::color( $header_icon['header_icon_hover_color'] );

			saddle_merge_value( $css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ], Saddle_Sanitize::margin( $header_icon['header_icon_margin'] ) );

			saddle_merge_value( $css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ], Saddle_Sanitize::padding( $header_icon['header_icon_padding'] ) );

			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['border-radius'] = Saddle_Sanitize::size( $header_icon['header_icon_border_radius'] . 'px' );

		endforeach;
	endif;

	// Header Ad.
	saddle_merge_value( $css['global']['.widget-header, .small-header .widget-header'], Saddle_Sanitize::margin( saddle_get_settings( 'mts_header_adcode_margin' ) ) );

	// Ad-Blocker.
	$css['global']['.navigation-banner']['background'] = Saddle_Sanitize::color( saddle_get_settings( 'navigation_ad_background' ) );

	// Floating Navigation Responsive
	if ( ! saddle_get_settings( 'sticky_responsive_nav' ) ) {

		$css['@media screen and (max-width: 865px)']['#catcher']['height'] = '0px!important';

		$css['@media screen and (max-width: 865px)']['.sticky-navigation-active']['position'] = 'relative!important';

		$css['@media screen and (max-width: 865px)']['.sticky-navigation-active']['top'] = '0px!important';

		$css['@media screen and (max-width: 865px)']['.admin-bar .sticky-navigation-active ']['top'] = '0px!important';

	};

}

/**
 * Header Featured Section
 *
 * @param array $css Array of dynamic CSS.
 */
function saddle_header_featured( &$css ) {

	$featured_section = saddle_get_settings( 'header_featured' );
	$header_layout    = saddle_get_settings( 'header_styles' );

	if ( ! $featured_section || ! is_page_template( 'page-home.php' ) || 'header-layout2' === $header_layout ) {
		return;
	}

	$css['global']['#site-header']['max-height'] = '100%';

	// Margin and Padding.
	saddle_merge_value( $css['global']['.featured-section'], Saddle_Sanitize::margin( saddle_get_settings( 'featured_margin' ) ) );
	saddle_merge_value( $css['global']['.featured-section'], Saddle_Sanitize::padding( saddle_get_settings( 'featured_padding' ) ) );

	// Typography.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'featured_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'featured_content_font' ) ) );

}

/**
 * Social Share Styling
 *
 * @param array $css Array of dynamic CSS.
 */
function saddle_single_social_buttons( &$css ) {

	// Social share.
	$css['global']['.shareit.floating'] = Saddle_Sanitize::background( saddle_get_settings( 'social_styling_background' ) );
	saddle_merge_value( $css['global']['.shareit.floating'], Saddle_Sanitize::margin( saddle_get_settings( 'social_styling_margin' ) ) );

	// Social share border.
	$social_border = Saddle_Sanitize::border( saddle_get_settings( 'social_styling_border' ) );
	$css['global']['.shareit.floating'][ $social_border ['direction'] ] = $social_border ['value'];

	$social_button_layout   = saddle_get_settings( 'social_button_layout' );
	$social_button_position = saddle_get_settings( 'social_floating_button_position' );
	if ( 'default' === $social_button_layout ) {
		$share_class = '.shareit.shareit-' . $social_button_layout . '.floating';
	} else {
		$share_class = '.shareit.' . $social_button_layout . '.floating';
	}
	if ( ! empty( $social_button_position ) && is_array( $social_button_position ) ) {
		foreach ( $social_button_position as $key => $position ) {
			$css['global'][ $share_class ][ $key ] = $position;
		}
	}
}

/**
 * Sidebar styling
 *
 * @param array $css Array of dynamic CSS.
 */
function saddle_sidebar_styling( &$css ) {

	// Sidebar.
	saddle_merge_value( $css['global']['.widget, .f-widget .widget'], Saddle_Sanitize::background( saddle_get_settings( 'sidebar_styling_background' ) ) );
	saddle_merge_value( $css['global']['.widget, .f-widget .widget'], Saddle_Sanitize::margin( saddle_get_settings( 'sidebar_styling_margin' ) ) );
	saddle_merge_value( $css['global']['.widget, .f-widget .widget'], Saddle_Sanitize::padding( saddle_get_settings( 'sidebar_styling_padding' ) ) );

	// Sidebar border.
	$sidebar_border = Saddle_Sanitize::border( saddle_get_settings( 'sidebar_styling_border' ) );
	$css['global']['.widget, .f-widget .widget'][ $sidebar_border['direction'] ] = $sidebar_border['value'];

	// Sidebar title.
	$sidebar_title                   = '#sidebar .widget h3, .cpt-sidebar .widget-title';
	$css['global'][ $sidebar_title ] = Saddle_Sanitize::background( saddle_get_settings( 'sidebar_title_styling_background' ) );
	saddle_merge_value( $css['global'][ $sidebar_title ], Saddle_Sanitize::padding( saddle_get_settings( 'sidebar_title_styling_padding' ) ) );
	saddle_merge_value( $css['global'][ $sidebar_title ], Saddle_Sanitize::margin( saddle_get_settings( 'sidebar_title_styling_margin' ) ) );

	// Sidebar Title border.
	$sidebar_title_border = Saddle_Sanitize::border( saddle_get_settings( 'widget_title_border' ) );
	$css['global'][ $sidebar_title ][ $sidebar_title_border['direction'] ] = $sidebar_title_border['value'];

}

/**
 * HomePage Sections
 *
 * @param array $css Array of dynamic CSS.
 */
function saddle_home_sections( &$css ) {

	// About Section.

	// Background.
	$css['global']['.about-section'] = Saddle_Sanitize::background( saddle_get_settings( 'about_background' ) );

	// Margin and Padding.
	saddle_merge_value( $css['global']['.about-section'], Saddle_Sanitize::margin( saddle_get_settings( 'about_margin' ) ) );
	saddle_merge_value( $css['global']['.about-section'], Saddle_Sanitize::padding( saddle_get_settings( 'about_padding' ) ) );

	// Typography.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'about_top_small_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'about_top_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'about_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'about_content_font' ) ) );

	// Services Section.

	// Background.
	$css['global']['.services-section'] = Saddle_Sanitize::background( saddle_get_settings( 'services_background' ) );

	// Margin and Padding.
	saddle_merge_value( $css['global']['.services-section'], Saddle_Sanitize::margin( saddle_get_settings( 'services_margin' ) ) );
	saddle_merge_value( $css['global']['.services-section'], Saddle_Sanitize::padding( saddle_get_settings( 'services_padding' ) ) );

	// Typography.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'services_top_small_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'services_top_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'services_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'services_content_font' ) ) );

	// Plans Section.

	$count      = 0;
	$plans_list = saddle_get_settings( 'plans_list' );

	if ( ! empty( $plans_list ) && is_array( $plans_list ) ) {
		foreach ( $plans_list as $plan ) {

			++$count;

			// Text Colors.
			$css['global'][ '.plans-wrapper li.plan-' . $count . ' .title' ]['color'] = Saddle_Sanitize::color( $plan['plans_list_title_color'] );

			$css['global'][ '.plans-wrapper li.plan-' . $count . ' .price' ]['color'] = Saddle_Sanitize::color( $plan['plans_list_price_color'] );

			$css['global'][ '.plans-wrapper li.plan-' . $count . ' p' ]['color'] = Saddle_Sanitize::color( $plan['plans_list_text_color'] );

			// Background Image and Color.
			if ( 'color' === $plan['plans_background_style'] ) {
				$css['global'][ '.plans-wrapper li.plan-' . $count ]['background-color'] = Saddle_Sanitize::color( $plan['plans_list_bg_color'] );
			} else {
				$css['global'][ '.plans-wrapper li.plan-' . $count ]['background-image'] = 'url(' . $plan['plans_list_bg_image'] . ');';
			}

			// Plan Margin and Padding.
			saddle_merge_value( $css['global'][ '.plans-wrapper li.plan-' . $count ], Saddle_Sanitize::margin( $plan['plans_list_margin'] ) );
			saddle_merge_value( $css['global'][ '.plans-wrapper li.plan-' . $count ], Saddle_Sanitize::padding( $plan['plans_list_padding'] ) );

		}
	}

	// Background.
	$css['global']['.plans-section'] = Saddle_Sanitize::background( saddle_get_settings( 'plans_background' ) );

	// Margin and Padding.
	saddle_merge_value( $css['global']['.plans-section'], Saddle_Sanitize::margin( saddle_get_settings( 'plans_margin' ) ) );
	saddle_merge_value( $css['global']['.plans-section'], Saddle_Sanitize::padding( saddle_get_settings( 'plans_padding' ) ) );

	// Typography.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'plans_top_small_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'plans_top_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'plans_top_desc_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'plans_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'plans_price_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'plans_content_font' ) ) );

	// Events Section.
	$event_image_position = saddle_get_settings( 'event_image_position' );

	// Background.
	$css['global']['.events-section'] = Saddle_Sanitize::background( saddle_get_settings( 'events_background' ) );

	// Image Position
	if ( $event_image_position && is_array( $event_image_position ) ) {
		foreach ( $event_image_position as $key => $position ) {
			$css['global']['.events-section .event-image'][ $key ] = $position;
		}
	}

	// Margin and Padding.
	saddle_merge_value( $css['global']['.events-section'], Saddle_Sanitize::margin( saddle_get_settings( 'events_margin' ) ) );
	saddle_merge_value( $css['global']['.events-section'], Saddle_Sanitize::padding( saddle_get_settings( 'events_padding' ) ) );

	// Typography.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'events_top_small_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'events_top_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'events_meta_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'events_title_font' ) ) );

	// Testimonials Section.

	// Background.
	$css['global']['.testimonials-section'] = Saddle_Sanitize::background( saddle_get_settings( 'testimonials_background' ) );

	// Margin and Padding.
	saddle_merge_value( $css['global']['.testimonials-section'], Saddle_Sanitize::margin( saddle_get_settings( 'testimonials_margin' ) ) );
	saddle_merge_value( $css['global']['.testimonials-section'], Saddle_Sanitize::padding( saddle_get_settings( 'testimonials_padding' ) ) );

	// Typography.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'testimonials_top_small_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'testimonials_top_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'testimonials_top_desc_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'testimonials_author_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'testimonial_font' ) ) );

	// Awards.

	$count       = 0;
	$awards_list = saddle_get_settings( 'awards_list' );

	if ( ! empty( $awards_list ) && is_array( $awards_list ) ) {
		foreach ( $awards_list as $award ) {

			// BG Color.
			$css['global'][ '.awards-wrapper li.award-' . ++$count ]['background-color'] = Saddle_Sanitize::color( $award['awards_list_bg_color'] );

		}
	}

	// Background.
	$css['global']['.awards-section'] = Saddle_Sanitize::background( saddle_get_settings( 'awards_background' ) );

	// Margin and Padding.
	saddle_merge_value( $css['global']['.awards-section'], Saddle_Sanitize::margin( saddle_get_settings( 'awards_margin' ) ) );
	saddle_merge_value( $css['global']['.awards-section'], Saddle_Sanitize::padding( saddle_get_settings( 'awards_padding' ) ) );

	// Typography.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'awards_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'awards_text_font' ) ) );

	// Our Blog.

	// Background.
	$css['global']['.blog-section'] = Saddle_Sanitize::background( saddle_get_settings( 'blog_background' ) );

	// Margin and Padding.
	saddle_merge_value( $css['global']['.blog-section'], Saddle_Sanitize::margin( saddle_get_settings( 'blog_margin' ) ) );
	saddle_merge_value( $css['global']['.blog-section'], Saddle_Sanitize::padding( saddle_get_settings( 'blog_padding' ) ) );

	// Typography.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'blog_top_small_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'blog_top_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'blog_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'blog_content_font' ) ) );

	// Call to Action.

	// Background.
	$css['global']['.cta-section'] = Saddle_Sanitize::background( saddle_get_settings( 'cta_background' ) );

	// Margin and Padding.
	saddle_merge_value( $css['global']['.cta-section'], Saddle_Sanitize::margin( saddle_get_settings( 'cta_margin' ) ) );
	saddle_merge_value( $css['global']['.cta-section'], Saddle_Sanitize::padding( saddle_get_settings( 'cta_padding' ) ) );

	// Typography.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'cta_title_font' ) ) );

	// Custom HTML.

	// Margin and Padding.
	saddle_merge_value( $css['global']['.html-section'], Saddle_Sanitize::margin( saddle_get_settings( 'html_margin' ) ) );
	saddle_merge_value( $css['global']['.html-section'], Saddle_Sanitize::padding( saddle_get_settings( 'html_padding' ) ) );

}

/**
 * Pages Title and Breadcrumb
 *
 * @param array $css Array of dynamic CSS.
 */
function saddle_page_titles( &$css ) {

	// Margin and Padding.
	saddle_merge_value( $css['global']['.pages-title-section'], Saddle_Sanitize::margin( saddle_get_settings( 'pages_title_margin' ) ) );
	saddle_merge_value( $css['global']['.pages-title-section'], Saddle_Sanitize::padding( saddle_get_settings( 'pages_title_padding' ) ) );

	// Typography.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'breadcrumb_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'pages_small_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'pages_title_font' ) ) );

}

/**
 * Layout CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function saddle_post_layouts( &$css ) {

	// Post Layouts.
	$features = saddle_get_settings( 'featured_categories' );
	foreach ( $features as $feature ) :

		if ( ! isset( $feature['unique_id'] ) ) {
			continue;
		}

		$category     = $feature['mts_featured_category'];
		$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : 'layout-default';
		$unique_id    = $feature['unique_id'];

		if ( 'layout-default' === $posts_layout ) :
			$posts_layout = 'default';
		endif;

		// Section title align.
		$post_title_align = saddle_get_settings( 'post_title_alignment_' . $unique_id );

		// Post area.
		$cat_class = 'cat-latest';
		if ( 'latest' !== $category ) {
			$category  = get_term_by( 'slug', $category, 'category' );
			$cat_class = sanitize_key( $category->name );
		}

		$title_class = '.title-container.title-id-' . $unique_id . ' h3';

		$css['global'][ $title_class ] = Saddle_Sanitize::background( saddle_get_settings( 'featured_category_title_background_' . $unique_id ) );
		saddle_merge_value( $css['global'][ $title_class ], Saddle_Sanitize::margin( saddle_get_settings( 'featured_category_title_margin_' . $unique_id ) ) );
		saddle_merge_value( $css['global'][ $title_class ], Saddle_Sanitize::padding( saddle_get_settings( 'featured_category_title_padding_' . $unique_id ) ) );
		// Section title border.
		$post_title_border = Saddle_Sanitize::border( saddle_get_settings( 'post_title_border_' . $unique_id ) );
		$css['global'][ $title_class ][ $post_title_border['direction'] ] = $post_title_border['value'];

		// Title alignment.
		$align_class = '.title-container.title-id-' . $unique_id;
		if ( 'center' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align'] = 'center';
		elseif ( 'right' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align']              = 'right';
			$css['global'][ $align_class . ' + .view-more' ]['left']  = '0';
			$css['global'][ $align_class . ' + .view-more' ]['right'] = 'auto';
		endif;

		saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'featured_category_title_font_' . $unique_id ) ) );

		if ( 'layout-default' === $posts_layout ) {
			$post_class = '.layout-' . $unique_id . '.default-container';
		} else {
			$post_class = '.layout-' . $unique_id;
		}

		// Post border.
		$post_border = Saddle_Sanitize::border( saddle_get_settings( 'post_border_' . $unique_id ) );
		$css['global'][ $post_class ][ $post_border['direction'] ] = $post_border['value'];

		/**
		 * Meta info
		 */
		saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'meta_info_font_' . $unique_id ) ) );

		saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'post_title_font_' . $unique_id ) ) );
		saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'post_excerpt_font_' . $unique_id ) ) );

		// All Posts Margin and Padding.
		saddle_merge_value( $css['global'][ $post_class ], Saddle_Sanitize::margin( saddle_get_settings( 'post_margin_' . $unique_id ) ) );
		saddle_merge_value( $css['global'][ $post_class ], Saddle_Sanitize::padding( saddle_get_settings( 'post_padding_' . $unique_id ) ) );

		if ( 'layout-full' === $posts_layout ) {
			$css['global'][ '.layout-' . $unique_id . ' .wrapper' ]['background-color'] = Saddle_Sanitize::color( saddle_get_settings( 'full_post_overlay_' . $unique_id ) );
		}

	endforeach;
}

/**
 * Pagination
 *
 * @param array $css Array of dynamic CSS.
 */
function saddle_post_pagination( &$css ) {

	// Pagination Active class.
	$pagination_class_active = array(
		'.pace .pace-progress',
		'.page-numbers.current',
		'.pagination a:hover',
	);
	$pagination_class        = array(
		'.pagination a',
		'.single .pagination > .current .currenttext',
		'.pagination .page-numbers.dots',
	);
	saddle_merge_value( $css['global'][ saddle_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Saddle_Sanitize::margin( saddle_get_settings( 'mts_pagenavigation_margin' ) ) );
	if ( '2' !== saddle_get_settings( 'mts_pagenavigation_type' ) || is_post_type_archive( 'horses' ) || is_post_type_archive( 'contests' ) ) {

		$css['global'][ saddle_implode( $pagination_class ) ]['background-color'] = Saddle_Sanitize::color( saddle_get_settings( 'mts_pagenavigation_bgcolor' ) );

		$css['global'][ saddle_implode( $pagination_class_active ) ]['background-color'] = Saddle_Sanitize::color( saddle_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );

		$css['global'][ saddle_implode( $pagination_class ) ]['color'] = Saddle_Sanitize::color( saddle_get_settings( 'mts_pagenavigation_color' ) );

		$css['global'][ saddle_implode( $pagination_class_active ) ]['color'] = Saddle_Sanitize::color( saddle_get_settings( 'mts_pagenavigation_hover_color' ) );

		saddle_merge_value( $css['global'][ saddle_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Saddle_Sanitize::padding( saddle_get_settings( 'mts_pagenavigation_padding' ) ) );
	} else {
		$css['global']['#load-posts a']['background-color'] = Saddle_Sanitize::color( saddle_get_settings( 'load_more_bgcolor' ) );

		$css['global']['#load-posts a:hover']['background-color'] = Saddle_Sanitize::color( saddle_get_settings( 'load_more_hover_bgcolor' ) );

		$css['global']['#load-posts a']['color'] = Saddle_Sanitize::color( saddle_get_settings( 'load_more_color' ) );

		$css['global']['#load-posts a:hover']['color'] = Saddle_Sanitize::color( saddle_get_settings( 'load_more_hover_color' ) );

		saddle_merge_value( $css['global']['#load-posts a'], Saddle_Sanitize::padding( saddle_get_settings( 'load_more_padding' ) ) );
	}

	$border_radius_class   = $pagination_class;
	$border_radius_class[] = '#load-posts a';

	// Border radius.
	$css['global'][ saddle_implode( $border_radius_class ) ]['border-radius'] = Saddle_Sanitize::size( saddle_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );

	$css['global'][ saddle_implode( $pagination_class_active ) ]['border-radius'] = Saddle_Sanitize::size( saddle_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );

	// Pagination border.
	$pagination_border = Saddle_Sanitize::border( saddle_get_settings( 'pagenavigation_border' ) );
	$css['global'][ saddle_implode( array_merge( $pagination_class_active, $border_radius_class ) ) ][ $pagination_border ['direction'] ] = $pagination_border ['value'];

	// Pagination Alignment.
	$pagenavigation_align = saddle_get_settings( 'pagenavigation_alignment' );
	if ( 'left' === $pagenavigation_align ) :
		$css['global']['.pagination']['text-align'] = 'left';
	elseif ( 'right' === $pagenavigation_align ) :
		$css['global']['.pagination']['text-align'] = 'right';
	endif;

	// Load more Alignment.
	$load_more_align = saddle_get_settings( 'load_more_alignment' );
	if ( 'left' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'left';
	elseif ( 'right' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'right';
	elseif ( 'full' === $load_more_align ) :
		$css['global']['#load-posts a']['width'] = '100%';
	endif;
}

/**
 * Single
 *
 * @param array $css Array of dynamic CSS.
 */
function saddle_single( &$css ) {

	// Single, Page and 404 Page Background.
	$page_classes = array(
		'.single_post',
		'.page .article',
		'.error404 .article',
	);

	$css['global'][ saddle_implode( $page_classes ) ] = Saddle_Sanitize::background( saddle_get_settings( 'single_background' ) );

	// Margin, Padding, Border and Box Shadow.
	saddle_merge_value( $css['global']['.article'], Saddle_Sanitize::margin( saddle_get_settings( 'mts_single_styling_margin' ) ) );
	saddle_merge_value( $css['global'][ saddle_implode( $page_classes ) ], Saddle_Sanitize::padding( saddle_get_settings( 'mts_single_styling_padding' ) ) );

	// Single border.
	$single_border = Saddle_Sanitize::border( saddle_get_settings( 'single_styling_border' ) );
	$css['global']['.article'][ $single_border ['direction'] ] = $single_border ['value'];

	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'mts_single_meta_info_font' ) ) );

	// Tags.
	$css['global']['.tags a, .tagcloud a, .widget .wpt_widget_content #tags-tab-content ul li a']['background-color'] = Saddle_Sanitize::color( saddle_get_settings( 'tags_bgcolor' ) );

	// Related Posts.
	$css['global']['.related-posts'] = Saddle_Sanitize::background( saddle_get_settings( 'related_posts_background' ) );

	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'related_posts_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'related_posts_meta_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'related_posts_excerpt_font' ) ) );

	saddle_merge_value( $css['global']['.related-posts'], Saddle_Sanitize::margin( saddle_get_settings( 'related_posts_margin' ) ) );
	saddle_merge_value( $css['global']['.related-posts'], Saddle_Sanitize::padding( saddle_get_settings( 'related_posts_padding' ) ) );

	$related_posts_border = Saddle_Sanitize::border( saddle_get_settings( 'related_posts_border' ) );
	$css['global']['.related-posts'][ $related_posts_border ['direction'] ] = $related_posts_border ['value'];

	// Related Posts articles.
	$css['global']['.related-posts article'] = Saddle_Sanitize::background( saddle_get_settings( 'related_article_background' ) );

	saddle_merge_value( $css['global']['.related-posts article'], Saddle_Sanitize::padding( saddle_get_settings( 'related_article_padding' ) ) );

	saddle_merge_value( $css['global']['.related-posts article .wrapper'], Saddle_Sanitize::padding( saddle_get_settings( 'related_article_text_padding' ) ) );

	// Box Shadow.
	if ( ! saddle_get_settings( 'related_article_shadow' ) ) {
		$css['global']['.related-posts article']['box-shadow'] = 'none';
	}

	// Subscribe Box.
	$css['global']['.single-subscribe .widget.wp_subscribe'] = Saddle_Sanitize::background( saddle_get_settings( 'single_subscribe_background' ) );
	saddle_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Saddle_Sanitize::margin( saddle_get_settings( 'single_subscribe_margin' ) ) );
	saddle_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Saddle_Sanitize::padding( saddle_get_settings( 'single_subscribe_padding' ) ) );
	$css['global']['.single-subscribe .widget.wp_subscribe']['border-radius'] = Saddle_Sanitize::size( saddle_get_settings( 'single_subscribe_border_radius' ) . 'px' );

	// Box Shadow.
	if ( ! saddle_get_settings( 'single_subscribe_shadow' ) ) {
		$css['global']['.single-subscribe .widget.wp_subscribe']['box-shadow'] = 'none';
	}

	// Subscribe border.
	$subscribe_border = Saddle_Sanitize::border( saddle_get_settings( 'single_subscribe_border' ) );
	$css['global']['.single-subscribe .widget.wp_subscribe'][ $subscribe_border ['direction'] ] = $subscribe_border ['value'];

	// Subscribe Box Input fields.
	$subscribe_input_class = array(
		'.single-subscribe #wp-subscribe input.email-field',
		'.single-subscribe #wp-subscribe input.name-field',
	);
	$css['global'][ saddle_implode( $subscribe_input_class ) ]['height'] = Saddle_Sanitize::size( saddle_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['height'] = Saddle_Sanitize::size( saddle_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['line-height'] = Saddle_Sanitize::size( saddle_get_settings( 'single_subscribe_input_height' ) + 6 . 'px' );

	$css['global'][ saddle_implode( $subscribe_input_class ) ]['border-radius'] = Saddle_Sanitize::size( saddle_get_settings( 'single_subscribe_input_border_radius' ) . 'px' );

	// Subscribe Box Input border.
	saddle_merge_value( $css['global'][ saddle_implode( $subscribe_input_class ) ], Saddle_Sanitize::border2( saddle_get_settings( 'single_subscribe_input_border' ) ) );

	// Subscribe Box Submit button.
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['background']    = Saddle_Sanitize::color( saddle_get_settings( 'single_subscribe_submit_backgroud' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['border-radius'] = Saddle_Sanitize::size( saddle_get_settings( 'single_subscribe_submit_border_radius' ) . 'px' );

	// Subscribe Box Submit border.
	$subscribe_box_submit_border = Saddle_Sanitize::border( saddle_get_settings( 'single_subscribe_submit_border' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit'][ $subscribe_box_submit_border ['direction'] ] = $subscribe_box_submit_border ['value'];

	saddle_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe input.submit'], Saddle_Sanitize::padding( saddle_get_settings( 'single_subscribe_submit_padding' ) ) );

	// Author Box.
	$css['global']['.postauthor'] = Saddle_Sanitize::background( saddle_get_settings( 'authorbox_background' ) );

	saddle_merge_value( $css['global']['.postauthor'], Saddle_Sanitize::margin( saddle_get_settings( 'authorbox_margin' ) ) );

	saddle_merge_value( $css['global']['.postauthor'], Saddle_Sanitize::padding( saddle_get_settings( 'authorbox_padding' ) ) );

	$css['global']['.postauthor']['border-radius'] = Saddle_Sanitize::size( saddle_get_settings( 'authorbox_border_radius' ) . 'px' );

	// Box Shadow.
	if ( ! saddle_get_settings( 'authorbox_shadow' ) ) {
		$css['global']['.postauthor']['box-shadow'] = 'none';
	}

	// Border.
	saddle_merge_value( $css['global']['.postauthor'], Saddle_Sanitize::border2( saddle_get_settings( 'authorbox_border' ) ) );

	// Author image.
	saddle_merge_value( $css['global']['.postauthor img'], Saddle_Sanitize::margin( saddle_get_settings( 'single_author_image_margin' ) ) );

	$css['global']['.postauthor img']['border-radius'] = Saddle_Sanitize::size( saddle_get_settings( 'single_author_image_border_radius' ) . 'px' );

	// Single Page titles Styling.
	$titles_align = saddle_get_settings( 'single_title_alignment' );

	$titles_align_class = array(
		'.comment-title',
		'#respond',
		'.related-posts-title',
	);
	$titles_class       = array(
		'#respond h4',
		'.total-comments',
		'.related-posts h4',
	);

	$css['global'][ saddle_implode( $titles_class ) ] = Saddle_Sanitize::background( saddle_get_settings( 'single_title_background' ) );
	saddle_merge_value( $css['global'][ saddle_implode( $titles_class ) ], Saddle_Sanitize::padding( saddle_get_settings( 'single_title_padding' ) ) );
	// Single title border.
	$single_titles_border = Saddle_Sanitize::border( saddle_get_settings( 'single_title_border' ) );
	$css['global'][ saddle_implode( $titles_class ) ][ $single_titles_border ['direction'] ] = $single_titles_border ['value'];

	if ( 'left' === $titles_align ) :
		$css['global'][ saddle_implode( $titles_class ) ]['display'] = 'inline-block';
	elseif ( 'center' === $titles_align ) :
		$css['global'][ saddle_implode( $titles_align_class ) ]['text-align'] = 'center';
		$css['global'][ saddle_implode( $titles_class ) ]['display']          = 'inline-block';
	elseif ( 'right' === $titles_align ) :
		$css['global'][ saddle_implode( $titles_align_class ) ]['text-align'] = 'right';
		$css['global'][ saddle_implode( $titles_class ) ]['display']          = 'inline-block';
	endif;

	// Comments.
	// Margin and Padding.
	saddle_merge_value( $css['global']['#comments'], Saddle_Sanitize::margin( saddle_get_settings( 'comments_margin' ) ) );
	saddle_merge_value( $css['global']['#comments'], Saddle_Sanitize::padding( saddle_get_settings( 'comments_padding' ) ) );
	saddle_merge_value( $css['global']['#comments li'], Saddle_Sanitize::margin( saddle_get_settings( 'comments_list_margin' ) ) );
	saddle_merge_value( $css['global']['#comments li'], Saddle_Sanitize::padding( saddle_get_settings( 'comments_list_padding' ) ) );
	saddle_merge_value( $css['global']['#comments .avatar'], Saddle_Sanitize::margin( saddle_get_settings( 'comments_list_image_margin' ) ) );

	// Author Comment.
	saddle_merge_value( $css['global']['#comments li.bypostauthor'], Saddle_Sanitize::margin( saddle_get_settings( 'comments_list_author_margin' ) ) );
	saddle_merge_value( $css['global']['#comments li.bypostauthor'], Saddle_Sanitize::padding( saddle_get_settings( 'comments_list_author_padding' ) ) );
	$css['global']['#comments li.bypostauthor']['background-color'] = Saddle_Sanitize::color( saddle_get_settings( 'author_comment_bg' ) );

	// Comment list.
	// Border.
	$single_titles_border = Saddle_Sanitize::border( saddle_get_settings( 'comments_list_border' ) );
	$css['global']['#comments li'][ $single_titles_border ['direction'] ] = $single_titles_border ['value'];

	$css['global']['#comments ul.children']['border-top'] = $single_titles_border ['value'];

	$css['global']['#comments .avatar']['border-radius'] = Saddle_Sanitize::size( saddle_get_settings( 'comments_list_image_border_radius' ) . 'px' );

	// Typography.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'comments_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'comments_meta_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'comments_text_font' ) ) );

}

/**
 * Footer
 *
 * @param array $css Array of dynamic CSS.
 */
function saddle_footer( &$css ) {

	// Footer.
	if ( saddle_get_settings( 'mts_top_footer' ) ) {
		saddle_merge_value( $css['global']['#site-footer'], Saddle_Sanitize::margin( saddle_get_settings( 'mts_top_footer_margin' ) ) );
		saddle_merge_value( $css['global']['#site-footer'], Saddle_Sanitize::padding( saddle_get_settings( 'mts_top_footer_padding' ) ) );
	}

}

/**
 * Copyrights
 *
 * @param array $css Array of dynamic CSS.
 */
function saddle_copyrights( &$css ) {

	// copyrights border.
	$copyrights_border = Saddle_Sanitize::border( saddle_get_settings( 'copyrights_border' ) );
	$css['global']['.copyrights'][ $copyrights_border ['direction'] ] = $copyrights_border ['value'];

	// Margin and padding.
	saddle_merge_value( $css['global']['.copyrights'], Saddle_Sanitize::margin( saddle_get_settings( 'copyrights_margin' ) ) );
	saddle_merge_value( $css['global']['.copyrights'], Saddle_Sanitize::padding( saddle_get_settings( 'copyrights_padding' ) ) );

}

/**
 * Archive
 *
 * @param array $css Array of dynamic CSS.
 */
function saddle_archive_post( &$css ) {

	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'archive_post_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'archive_post_excerpt_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'archive_meta_info_font' ) ) );

}

/**
 * Misc
 *
 * @param array $css Array of dynamic CSS.
 */
function saddle_misc_css( &$css ) {

	// Show Logo.
	$show_logo = saddle_get_settings( 'hide_logo' );

	if ( 0 === $show_logo ) {
		$css['global']['.logo-wrap']['display'] = 'none';
	}

	// Back to top.
	$css['global']['#move-to-top']['background-color'] = Saddle_Sanitize::color( saddle_get_settings( 'top_button_background' ) );

	$css['global']['#move-to-top:hover']['background-color'] = Saddle_Sanitize::color( saddle_get_settings( 'top_button_background_hover' ) );

	// Border.
	$top_button_border = Saddle_Sanitize::border( saddle_get_settings( 'top_button_border' ) );
	$css['global']['#move-to-top'][ $top_button_border ['direction'] ] = $top_button_border ['value'];
	// Font-size, Padding and Position.
	$css['global']['#move-to-top .fa']['font-size'] = Saddle_Sanitize::size( saddle_get_settings( 'top_button_font_size' ) . 'px' );
	saddle_merge_value( $css['global']['#move-to-top'], Saddle_Sanitize::padding( saddle_get_settings( 'top_button_padding' ) ) );
	$top_button_position = saddle_get_settings( 'top_button_position' );
	foreach ( $top_button_position as $key => $position ) {
		$css['global']['#move-to-top'][ $key ] = $position;
	}
	// Border-radius.
	$css['global']['#move-to-top']['border-radius'] = Saddle_Sanitize::size( saddle_get_settings( 'top_button_border_radius' ) . 'px' );
	// Colors.
	$css['global']['#move-to-top']['color']       = Saddle_Sanitize::color( saddle_get_settings( 'top_button_color' ) );
	$css['global']['#move-to-top:hover']['color'] = Saddle_Sanitize::color( saddle_get_settings( 'top_button_color_hover' ) );

	$css['global']['#move-to-top:hover']['border-color'] = Saddle_Sanitize::color( saddle_get_settings( 'top_button_background_hover' ) );

	// Full width Related Posts.
	if ( 'full' === saddle_get_settings( 'related_posts_position' ) ) {
		$css['global']['.single .article']['margin-bottom'] = '0px';
	}

}

/**
 * Horses and Contests CPT
 *
 * @param array $css Array of dynamic CSS.
 */
function saddle_custom_posts( &$css ) {

	// Horses Posts Typography.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'horse_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'horse_info_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'horse_content_font' ) ) );

	// Contests Posts Typography.
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'contests_archive_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'contests_archive_desc_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'contests_date_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'contests_title_font' ) ) );
	saddle_map_css_selectors( $css['global'], Saddle_Sanitize::typography( saddle_get_settings( 'contests_info_font' ) ) );

}
